@@ -191,11 +191,12 @@ class MenuExtension(GObject.GObject, Nemo.MenuProvider):
     def check_registered_paths(self, filename):
         topLevelFolder = False
         internalFile = False
+        absfilename = os.path.realpath(filename)
         for reg_path in socketConnect.registered_paths:
-            if filename == reg_path:
+            if absfilename == reg_path:
                 topLevelFolder = True
                 break
-            if filename.startswith(reg_path):
+            if absfilename.startswith(reg_path):
                 internalFile = True
                 # you can't have a registered path below another so it is save to break here
                 break
@@ -208,6 +209,7 @@ class MenuExtension(GObject.GObject, Nemo.MenuProvider):
         all_internal_files = True
         for i, file_uri in enumerate(files):
             filename = get_local_path(file_uri.get_uri())
+            filename = os.path.realpath(filename)
 
             # Check if its a folder (ends with an /), if yes add a "/"
             # otherwise it will not find the entry in the table
@@ -296,6 +298,7 @@ class MenuExtension(GObject.GObject, Nemo.MenuProvider):
         state = entry['state']
         state_ok = state.startswith('OK')
         state_sync = state.startswith('SYNC')
+        isDir = os.path.isdir(filename + os.sep)
         if state_ok:
             shareable = True
         elif state_sync and isDir:
@@ -446,6 +449,7 @@ class SyncStateExtension(GObject.GObject, Nemo.InfoProvider):
             return
 
         filename = get_local_path(item.get_uri())
+        filename = os.path.realpath(filename)
         if item.is_directory():
             filename += os.sep
 
